<?php
/**
 * Theme functions and definitions
 *
 * Set up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 *
 * @link https://codex.wordpress.org/Theme_Development
 * @link https://codex.wordpress.org/Child_Themes
 *
 *
 * For more information on hooks, actions, and filters,
 * @link https://codex.wordpress.org/Plugin_API
 *
 * @package WordPress
 * @subpackage BlogoLife
 * @since BlogoLife 3.0.0
 * @author Valeriu Tihai
 * @author Stylish WordPress Themes
 * @link https://stylishwp.com
 */

/*------------------------------------------------------------
	Define Constants
============================================================*/

define( 'BLOGOLIFE_PRO', false );

/*------------------------------------------------------------
	Initializations
============================================================*/

require( trailingslashit( get_template_directory() ) . '/inc/init.php' );

/*------------------------------------------------------------
	Include Theme specific functionality
============================================================*/

if ( ! function_exists( 'blogolife_initiate_files' ) ) {

	function blogolife_initiate_files() {

		// Include Library
		require( trailingslashit( get_template_directory() ). '/inc/library.php' );
		require( trailingslashit( get_template_directory() ). '/inc/toolbar-be.php' );
		require( trailingslashit( get_template_directory() ). '/inc/customize-colors.php' );
		require( trailingslashit( get_template_directory() ). '/inc/customize.php' );
		require( trailingslashit( get_template_directory() ). '/inc/old-settings.php' );

		// Include Widgets
		require( trailingslashit( get_template_directory() ). '/inc/widgets/widget-init.php' );
		require( trailingslashit( get_template_directory() ). '/inc/widgets/widget-tabs.php' );

	}
	add_action( 'after_setup_theme', 'blogolife_initiate_files' );
}
