<?php
/**
 * The header template
 *
 * @package WordPress
 * @subpackage BlogoLife
 * @since BlogoLife 3.0.0
 * @author Valeriu Tihai
 * @author Stylish WordPress Themes
 * @link https://stylishwp.com
 */
 	$blogolife_name_align = get_theme_mod( 'blogolife_name_align' );
 	$blogolife_logo = get_theme_mod( 'blogolife_logo' );
?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
	<head>
		<meta charset="<?php bloginfo( 'charset' ); ?>" />
		<meta name="viewport" content="width=device-width, initial-scale=1.0">
		<meta http-equiv="x-ua-compatible" content="IE=edge" >
		<?php wp_head(); ?>
	</head>
	<body <?php body_class(); ?>>
	<div class="off-canvas-wrapper">
	<div class="off-canvas-wrapper-inner" data-off-canvas-wrapper>
	<div class="off-canvas position-right" id="mobile-nav" data-off-canvas data-position="right">
		<?php
			if ( has_nav_menu( 'blogolife_main_menu' ) ) {
				wp_nav_menu(array(
					'container' => false,
					'menu_class' => 'vertical menu blogolife_mobile_menu blogolife-gradient',
					'items_wrap' => '<ul id="%1$s" class="%2$s" >%3$s</ul>',
					'theme_location' => 'blogolife_main_menu',
					'depth' => 5,
					'fallback_cb' => false,
					'walker' => new Blogolife_Walker_Mobile_Menu(),
				));
			}
		 ?>

	</div>
	<div class="off-canvas-content" data-off-canvas-content>
		<div class="row">
			<div class="columns">
				<div class="row collapse">
					<div class="columns blogolife_page">
						<div class="row">
							<?php if ( has_nav_menu( 'blogolife_main_menu' ) ) : ?>
								<div class="columns toolbar-mobile blogolife-gradient show-for-small-only">
									<div class="text-right">
										<span class="mobile-btn right" data-toggle="mobile-nav"></span>
									</div>
								</div>
							<?php endif; ?>
							<div class="columns">
								<div class="site-name">
									<?php if ($blogolife_logo != '') : ?>
										<p class="<?php echo esc_attr($blogolife_name_align); ?>">
											<a href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php bloginfo('name'); ?>">
												<img src="<?php echo esc_url($blogolife_logo); ?>" alt="<?php bloginfo('name'); ?>" />
											</a>
										</p>
									<?php else : ?>
										<h1 id="site-title" class="<?php echo esc_attr($blogolife_name_align); ?>">
											<a href="<?php echo esc_url( home_url( '/' ) ); ?>">
												<?php bloginfo('name'); ?>
											</a>
										</h1>
										<h2 id="site-description" class="<?php echo esc_attr($blogolife_name_align); ?>"><?php bloginfo('description'); ?></h2>
									<?php endif;  ?>
								</div>
							</div>
						</div>
						<?php if ( has_nav_menu( 'blogolife_social_menu' ) ) : ?>
							<div class="row collapse">
								<div class="columns">
									<nav id="blogolife_social_menu" class="blogolife_social_menu" role="navigation" aria-label="<?php esc_attr_e( 'Social Links Menu', 'blogolife' ); ?>">
										<?php
											wp_nav_menu( array(
												'theme_location' => 'blogolife_social_menu',
												'menu_class'     => 'social-links-menu',
												'depth'          => 1,
												'link_before'    => '<span class="screen-reader-text">',
												'link_after'     => '</span>',
											) );
										?>
									</nav><!-- .social-navigation -->
								</div>
							</div>
						<?php endif; ?>
						<div class="row collapse">
							<div class="columns  hide-for-small-only ">
								<?php
									if ( has_nav_menu( 'blogolife_main_menu' ) ) {
										wp_nav_menu(array(
											'container' => 'nav',
											'menu_class' => 'dropdown menu blogolife_main_menu blogolife-gradient',
											'items_wrap' => '<ul id="%1$s" class="%2$s" data-dropdown-menu>%3$s</ul>',
											'theme_location' => 'blogolife_main_menu',
											'depth' => 5,
											'fallback_cb' => false,
											'walker' => new Blogolife_Walker_Main_Menu(),
										));
									}
								 ?>
							</div>
						</div>
					<?php if ( !( wp_attachment_is_image() OR get_theme_mod( 'blogolife_header_img' ) == 'off'  ) ) : ?>
						<div class="row collapse">
							<div class="columns header-image">
								<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>">
									<?php if ( get_header_image() ) : ?>
										<img src="<?php header_image(); ?>" width="<?php echo esc_attr( get_custom_header()->width ); ?>" height="<?php echo esc_attr( get_custom_header()->height ); ?>" alt="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>">
									<?php else :  ?>
									<img src="<?php echo esc_url (get_template_directory_uri() . '/assets/images/header.jpg'); ?>" alt="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>">
									<?php endif; // End header image check. ?>
								</a>
							</div>
						</div>
					<?php endif; ?>
