<?php
/**
 * Theme initializations
 *
 * @package WordPress
 * @subpackage BlogoLife
 * @since BlogoLife 3.0.0
 * @author Valeriu Tihai
 * @author Stylish WordPress Themes
 * @link https://stylishwp.com
 */

/*------------------------------------------------------------
* Set the content width based on the theme's design and stylesheet.
============================================================*/
if ( ! function_exists( 'blogolife_content_width' ) ) :
	function blogolife_content_width() {
		$GLOBALS['content_width'] = apply_filters( 'blogolife_content_width', 830 );
	}
	add_action( 'after_setup_theme', 'blogolife_content_width', 0 );
endif;


/*------------------------------------------------------------
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
============================================================*/
if ( ! function_exists( 'blogolife_setup' ) ) :
function blogolife_setup() {

	// Make theme available for translation.
	load_theme_textdomain( 'blogolife', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	// Let WordPress manage the document title.
	add_theme_support( 'title-tag' );

	// Add support for a variety of post formats
	add_theme_support( 'post-formats', array( 'aside', 'audio', 'chat', 'gallery', 'image', 'link', 'quote', 'status', 'video'  ) );

	//Enable support for Post Thumbnails on posts and pages.
	add_theme_support( 'post-thumbnails' );
	//set_post_thumbnail_size( 850, 478, true );

	update_option( 'thumbnail_size_w', 250 );
	update_option( 'thumbnail_size_h', 141 );

	update_option( 'medium_size_w', 850 );
	update_option( 'medium_size_h', 478 );
	update_option( 'medium_crop', 1 );

	update_option( 'large_size_w', 1200 );
	update_option( 'large_size_h', 675 );
	update_option( 'large_crop', 1 );


	//Add theme Support Custom Background
	add_theme_support( 'custom-background');

	// Add default headers
	register_default_headers( array(
		'headerimage' => array(
			'url'           => get_template_directory_uri() . '/assets/images/header.jpg',
			'thumbnail_url' => get_template_directory_uri() . '/assets/images/header-t.jpg',
			'description'   => __( 'Girls - by Kevin Schmitz', 'blogolife' )
		),
	) );
	//Add theme Support  Custom Header
	$blogolife_custom_header_defaults = array(
		'default-image'          => '',
		'width'                  => 1200,
		'height'                 => 450,
		'flex-height'            => true,
		'flex-width'             => true,
		'uploads'                => true,
		'random-default'         => false,
		'header-text'            => false,
		'default-text-color'     => '',
		'wp-head-callback'       => '',
		'admin-head-callback'    => '',
		'admin-preview-callback' => '',
	);
	add_theme_support( 'custom-header', $blogolife_custom_header_defaults );


	// This theme uses wp_nav_menu().
	register_nav_menus( array(
		'blogolife_main_menu'    => __( 'Blogolife Main Menu', 'blogolife' ),
		'blogolife_social_menu'  => __( 'Blogolife Social Links Menu', 'blogolife' ),

	) );
	// This theme uses wp_nav_menu() in two locations.

	// Switch default core markup for search form, comment form, and comments to output valid HTML5.
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
	) );


}
endif; // blogolife_setup
add_action( 'after_setup_theme', 'blogolife_setup' );

/*------------------------------------------------------------
 * Enqueue scripts and styles.
============================================================*/
if ( ! function_exists( 'blogolife_scripts' ) ) :
	function blogolife_scripts() {

		// Load our main stylesheet.
		wp_enqueue_style( 'blogolife-style', get_stylesheet_uri(), array( 'blogolife-vendors' ), blogolife_get_theme_version(), 'all' );

		// Load the Vendors specific stylesheet.
		wp_enqueue_style( 'blogolife-vendors', get_template_directory_uri() . '/assets/styles/vendors.min.css', array(), blogolife_get_theme_version(), 'all' );

		// Add custom fonts, used in the main stylesheet.
		wp_enqueue_style( 'blogolife-google-fonts-roboto', 'https://fonts.googleapis.com/css?family=Roboto:400,300,300italic,400italic,700,700italic,900italic,900,500italic,500,100italic,100', array( 'blogolife-style' ), blogolife_get_theme_version(), 'all' );

		// Add custom fonts, used in the main stylesheet.
		wp_enqueue_style( 'blogolife-google-fonts-arimo', 'https://fonts.googleapis.com/css?family=Arimo:400,700&subset=latin,cyrillic-ext,latin-ext,cyrillic,greek', array( 'blogolife-style' ), blogolife_get_theme_version(), 'all' );

		// Load jQuery
		wp_enqueue_script('jquery');

		// Load the Vendors specific javascripts.
		wp_enqueue_script( 'blogolife-vendors', get_template_directory_uri() . '/assets/scripts/vendors.min.js', array( 'jquery' ), blogolife_get_theme_version(), true );

		// Load our javascripts
		wp_enqueue_script( 'blogolife-main', get_template_directory_uri() . '/assets/scripts/blogolife.js', array('blogolife-vendors'), blogolife_get_theme_version(), true );

		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

	}
	add_action( 'wp_enqueue_scripts', 'blogolife_scripts' );
endif;
